@@ -1,5 +1,5 @@
 use crate::ToSVG;
-use dessin::{shape::*, style::*, Shape, ShapeType, Vec2};
+use dessin::{shape::*, style::*, Shape, ShapeType};
 use std::error::Error;
 
 impl ToSVG for Shape {
@@ -37,62 +37,6 @@ impl ToSVG for Shape {
                 r = radius,
                 style = self.style.to_svg()?,
             )),
-            ShapeType::Arc {
-                inner_radius,
-                outer_radius,
-                start_angle,
-                end_angle,
-            } => {
-                let pos = self.pos.position_from_center();
-
-                let start = if start_angle.to_deg() >= 0. {
-                    start_angle.to_deg()
-                } else {
-                    start_angle.to_deg() + 360.
-                } % 360.;
-
-                let end = if end_angle.to_deg() >= 0. {
-                    end_angle.to_deg()
-                } else {
-                    end_angle.to_deg() + 360.
-                } % 360.;
-
-                let lower_left = Vec2::from_polar_deg(*inner_radius, start) + pos;
-                let upper_left = Vec2::from_polar_deg(*outer_radius, start) + pos;
-                let lower_right = Vec2::from_polar_deg(*inner_radius, end) + pos;
-                let upper_right = Vec2::from_polar_deg(*outer_radius, end) + pos;
-
-                let mut span = end - start;
-                span = if span >= 0. { span } else { span + 360. } % 360.;
-                let large_arc_flag = if span >= 180. { 1 } else { 0 };
-
-                let res = format!(r#"<path d="M {x} {y} "#, x = lower_left.x, y = lower_left.y);
-                let res = format!("{}L {x}, {y} ", res, x = upper_left.x, y = upper_left.y);
-
-                let res = format!(
-                    "{}A {r} {r} {s} {f} 1 {x}, {y} ",
-                    res,
-                    r = outer_radius,
-                    s = span,
-                    f = large_arc_flag,
-                    x = upper_right.x,
-                    y = upper_right.y
-                );
-
-                let res = format!("{}L {x}, {y} ", res, x = lower_right.x, y = lower_right.y);
-                let res = format!(
-                    "{}A {r} {r} {s} {f} 0 {x}, {y} ",
-                    res,
-                    r = inner_radius,
-                    s = span,
-                    f = large_arc_flag,
-                    x = lower_left.x,
-                    y = lower_left.y
-                );
-
-                let res = format!(r#"{}Z" {style}></path>"#, res, style = self.style.to_svg()?,);
-                Ok(res)
-            }
             ShapeType::Image { data } => Ok(format!(
                 r#"<image x="{x}" y="{y}" width="{width}" height="{height}" xlink:href="{href}"/>"#,
                 x = pos.x,
@@ -125,18 +69,20 @@ impl ToSVG for Shape {
                         .iter()
                         .map(|v| match v {
                             Keypoint::Point(p) => format!("L {} {} ", p.x, p.y),
-                            Keypoint::Bezier {
-                                destination,
-                                start_prop,
-                                dest_prop,
+                            Keypoint::BezierQuad { to, control } =>
+                                format!("Q {} {} {} {} ", control.x, control.y, to.x, to.y,),
+                            Keypoint::BezierCubic {
+                                to,
+                                control_from,
+                                control_to,
                             } => format!(
                                 "C {} {} {} {} {} {} ",
-                                start_prop.x,
-                                start_prop.y,
-                                dest_prop.x,
-                                dest_prop.y,
-                                destination.x,
-                                destination.y,
+                                control_from.x,
+                                control_from.y,
+                                control_to.x,
+                                control_to.y,
+                                to.x,
+                                to.y,
                             ),
                         })
                         .collect::<String>(),
@@ -223,7 +169,7 @@ impl ToSVG for Color {
     fn to_svg(&self) -> Result<String, Box<dyn Error>> {
         let c = self.rgba();
         if let Color::RGBA { r, g, b, a } = c {
-            Ok(format!("rgba({},{},{},{})", r, g, b, a))
+            Ok(format!("rgba({},{},{},{})", r, g, b, a as f32 / 255.))
         } else {
             unreachable!()
         }
@@ -254,7 +200,7 @@ mod tests {
                 .with_align(TextAlign::Center),
         );
 
-        let text_svg = r#"<text x="10" y="10" text-anchor="middle" font-size="10" font-weight="bold" fill='#FF0000FF' >hello world</text>"#;
+        let text_svg = r#"<text x="10" y="10" text-anchor="middle" font-size="10" font-weight="bold" fill='rgba(255,0,0,1)' >hello world</text>"#;
         let drawing_svg = format!(
             r#"<svg width="0px" height="0px" viewBox="-0 -0 0 0">{}</svg>"#,
             text_svg
@@ -272,7 +218,7 @@ mod tests {
                 .to(vec2(20., 20.))
                 .with_fill(Fill::Color(Color::U32(0xFF0000))),
         );
-        let line_svg = r#"<line x1="10" y1="10" x2="20" y2="20" fill='#FF0000' />"#;
+        let line_svg = r#"<line x1="10" y1="10" x2="20" y2="20" fill='rgba(255,0,0,1)' />"#;
         let drawing_svg = format!(
             r#"<svg width="0px" height="0px" viewBox="-0 -0 0 0">{}</svg>"#,
             line_svg
@@ -305,15 +251,15 @@ mod tests {
             g: 0x34,
             b: 0x56,
         };
-        assert_eq!(rgb.to_svg().unwrap(), "#123456");
+        assert_eq!(rgb.to_svg().unwrap(), "rgba(18,52,86,1)");
 
         let u = Color::U32(0x12345678);
-        assert_eq!(u.to_svg().unwrap(), "#12345678");
+        assert_eq!(u.to_svg().unwrap(), "rgba(52,86,120,1)");
 
         let red = Color::U32(0xFF0000);
-        assert_eq!(red.to_svg().unwrap(), "#FF0000");
+        assert_eq!(red.to_svg().unwrap(), "rgba(255,0,0,1)");
 
         let blue = Color::U32(0x0000FF);
-        assert_eq!(blue.to_svg().unwrap(), "#0000FF");
+        assert_eq!(blue.to_svg().unwrap(), "rgba(0,0,255,1)");
     }
 }
